@@ -1,6 +1,7 @@
 from timm.models.layers import drop_path
 import torch.nn as nn
 
+
 class DropPath(nn.Module):
     """Drop paths (Stochastic Depth) per sample  (when applied in main path of residual blocks).
     """
@@ -10,6 +11,6 @@ class DropPath(nn.Module):
 
     def forward(self, x):
         return drop_path(x, self.drop_prob, self.training)
-    
-    def extra_repr(self) -> str:
-        return 'p={}'.format(self.drop_prob)
\ No newline at end of file
+
+    def extra_repr(self):
+        return 'p={}'.format(self.drop_prob)
