@@ -1,15 +1,14 @@
-import math
 import copy
 import torch
 import torch.nn as nn
-import torch.nn.functional as F
-from apex.normalization import FusedLayerNorm as LayerNorm
+
 
 def MultiwayWrapper(args, module, dim=0):
     if args.multiway:
         return MultiwayNetwork(module, dim=dim)
     return module
 
+
 def set_split_position(position):
 
     def apply_fn(module):
@@ -18,8 +17,9 @@ def set_split_position(position):
 
     return apply_fn
 
+
 class MultiwayNetwork(nn.Module):
-    
+
     def __init__(self, module, dim=0):
         super().__init__()
         self.dim = dim
@@ -27,7 +27,7 @@ class MultiwayNetwork(nn.Module):
         self.B = copy.deepcopy(module)
         self.B.reset_parameters()
         self.split_position = -1
-    
+
     def forward(self, x, **kwargs):
         if self.split_position == -1:
             return self.A(x, **kwargs)
@@ -36,4 +36,4 @@ class MultiwayNetwork(nn.Module):
         x1, x2 = torch.split(x, [self.split_position, x.size(self.dim)-self.split_position], dim=self.dim)
         # x1, x2 = x[:self.split_position], x[self.split_position:]
         y1, y2 = self.A(x1, **kwargs), self.B(x2, **kwargs)
-        return torch.cat([y1, y2], dim=self.dim)
\ No newline at end of file
+        return torch.cat([y1, y2], dim=self.dim)
