@@ -16,12 +16,11 @@ import math
 import torch
 from torch import Tensor
 import torch.nn.functional as F
-import numpy as np
 
 from .moe_layer import has_tutel, fused_cumsum_sub_one
 
-#use a fixed temperature to compute balance loss
-TEMPERATURE_FOR_L_UAX=0.07
+# use a fixed temperature to compute balance loss
+TEMPERATURE_FOR_L_UAX = 0.07
 
 # maximum capacity of 1 expert as a fraction of number of tokens in the batch
 # Note: setting this to 1.0 causes inference to significantly slow down
@@ -75,7 +74,6 @@ def top1gating(
     metadata["expert1_balance_top"] = expert1_hist[:sample_count].sum()
     metadata["expert1_balance_bottom"] = expert1_hist[-sample_count:].sum()
 
-
     gates1_s = (gates * mask1).sum(dim=1)
 
     # Compute locations in capacity buffer
@@ -84,33 +82,13 @@ def top1gating(
     # Compute l_aux
     me = torch.mean(gates, dim=0)
     ce = torch.mean(mask1.to(gates.dtype), dim=0)
-    # if not use_xmoe:
-    #     me = torch.mean(gates, dim=0)
-    #     ce = torch.mean(mask1.to(gates.dtype), dim=0)
-    #     ####### Code for unused penalty #######
-    #     # l_aux2 = 0
-    #     # UNUSED_PENALTY_WEIGHT = 0
-    #     ####### Code for unused penalty #######
-    # else:
-    #     me = torch.mean(gates_for_l_aux, dim=0)
-    #     ce = torch.mean(mask1.to(gates_for_l_aux.dtype), dim=0)
-    #     # ce = ce - (1.0 / float(num_experts))
-    #     ####### Code for unused penalty #######
-    #     # aux2_diff = ce - 1.0 / num_experts
-    #     # aux2_mask = ce - 0.5 / num_experts < 0
-    #     # l_aux2 = torch.mean(me * aux2_diff * aux2_mask.to(me.dtype))
-    #     # UNUSED_PENALTY_WEIGHT = 100.0
-    #     ####### Code for unused penalty #######
 
     l_aux = torch.mean(me * ce)
-    ####### Code for unused penalty #######
-    # l_aux = UNUSED_PENALTY_WEIGHT * l_aux2 + l_aux
-    ####### Code for unused penalty #######
     l_aux = l_aux * num_experts * num_experts
 
     if has_tutel:
         locations1_s = torch.sum(locations1 * mask1, dim=1)
-        return l_aux, metadata, capacity, num_experts, [indices1_s,], [locations1_s,], [gates1_s,]
+        return l_aux, metadata, capacity, num_experts, [indices1_s, ], [locations1_s, ], [gates1_s, ]
 
     # Remove locations outside capacity from mask
     mask1 = mask1 * torch.lt(locations1, capacity)
@@ -168,14 +146,9 @@ class Top1Gate(torch.nn.Module):
             self.wg = torch.nn.Linear(model_dim, num_experts, bias=False)
         else:
             self.wg_reduction = torch.nn.Linear(model_dim, 16, bias=False)
-            # self.wg = torch.nn.Linear(16, num_experts, bias=False)
-            # torch.nn.init.orthogonal_(self.wg.weight, gain=0.1)
             wg = torch.empty(num_experts, 16)
             torch.nn.init.orthogonal_(wg, gain=0.32)
             self.register_parameter("wg", torch.nn.Parameter(wg))
-            # scaling rule: 0.3 / ln(#experts / 32)
-            # self.gating_t = torch.nn.Parameter(torch.FloatTensor(1).fill_(np.log(1.0 / 0.2)))
-            # self.gating_t = torch.nn.Parameter(torch.FloatTensor(1).fill_(np.log(1.0 / 0.07)))
 
         self.use_xmoe = use_xmoe
         self.use_fp32 = use_fp32
@@ -183,7 +156,7 @@ class Top1Gate(torch.nn.Module):
         self.capacity_factor = capacity_factor
         self.moe_eval_capacity_token_fraction = moe_eval_capacity_token_fraction
 
-    def forward(self, input: torch.Tensor, mask: Optional[torch.Tensor] = None,) -> Tuple[Tensor, Tensor, Tensor, Dict]:  # type: ignore
+    def forward(self, input, mask=None):  # type: ignore
         if self.use_xmoe:
             input = self.wg_reduction(input)
             with torch.no_grad():
@@ -193,7 +166,7 @@ class Top1Gate(torch.nn.Module):
             logits = self._make_finite(logits)
         else:
             logits = self.wg(input)
-        
+
         return top1gating(
             logits,
             mask,
@@ -225,7 +198,6 @@ class Top1Gate(torch.nn.Module):
         return mat1.float().matmul(mat2.transpose(0, 1)).type_as(mat1)
 
 
-
 gumbel_map: Dict[torch.device, Callable] = {}
 
 
@@ -321,11 +293,11 @@ def top2gating(
         importance_scores = -1 * gates.max(dim=1)[0]
         sorted_mask1 = mask1[importance_scores.argsort(dim=0)]
         sorted_cumsum1 = fused_cumsum_sub_one(sorted_mask1) * sorted_mask1
-        importance_sorted_locations1 =  sorted_cumsum1[importance_scores.argsort(dim=0).argsort(dim=0)]
+        importance_sorted_locations1 = sorted_cumsum1[importance_scores.argsort(dim=0).argsort(dim=0)]
 
         sorted_mask2 = mask2[importance_scores.argsort(dim=0)]
         sorted_cumsum2 = fused_cumsum_sub_one(sorted_mask2) * sorted_mask2
-        importance_sorted_locations2 =  sorted_cumsum2[importance_scores.argsort(dim=0).argsort(dim=0)]
+        importance_sorted_locations2 = sorted_cumsum2[importance_scores.argsort(dim=0).argsort(dim=0)]
 
         importance_sorted_locations2 += torch.sum(mask1, dim=0, keepdim=True)
 
@@ -342,7 +314,6 @@ def top2gating(
     l_aux = torch.mean(me * ce)
     l_aux = l_aux * num_experts * num_experts
 
-
     # for logging purposes
     metadata["overflow_expert1"] = 100 * torch.sum(mask1 * torch.ge(locations1, capacity)) / torch.sum(mask1)
     metadata["overflow_expert2"] = 100 * torch.sum(mask2 * torch.ge(locations2, capacity)) / torch.sum(mask2)
@@ -359,13 +330,12 @@ def top2gating(
 
     expert2_hist = 100 * torch.histc((indices2_s.squeeze() + 1), bins=num_experts, min=1, max=num_experts) / num_tokens
     metadata["unused_expert2_count"] = (expert2_hist == 0).sum()
-    expert2_hist = torch.sort(expert2_hist, dim=0, descending=True).values +  torch.finfo(torch.float32).tiny
+    expert2_hist = torch.sort(expert2_hist, dim=0, descending=True).values + torch.finfo(torch.float32).tiny
 
     sample_count = max(math.ceil(num_experts * SAMPLE_FRACTION), 1)
     metadata["expert1_balance_top"] = expert1_hist[:sample_count].sum()
     metadata["expert1_balance_bottom"] = expert1_hist[-sample_count:].sum()
 
-
     metadata["expert2_balance_top"] = expert2_hist[:sample_count].sum()
     metadata["expert2_balance_bottom"] = expert2_hist[-sample_count:].sum()
 
@@ -452,8 +422,8 @@ class Top2Gate(torch.nn.Module):
         self.moe_eval_capacity_token_fraction = moe_eval_capacity_token_fraction
         self.batch_prioritized_routing = batch_prioritized_routing
         self.use_xmoe = use_xmoe
-        
-    def forward(self, input: torch.Tensor, mask: Optional[torch.Tensor] = None,) -> Tuple[Tensor, Tensor, Tensor]:  # type: ignore
+
+    def forward(self, input, mask=None):  # type: ignore
         if self.use_xmoe:
             input = self.wg_reduction(input)
             with torch.no_grad():
@@ -480,7 +450,7 @@ class Top2Gate(torch.nn.Module):
         # mat1 = F.normalize(mat1, p=2.0, dim=1, eps=eps)
         mat2 = F.normalize(mat2.float(), p=2.0, dim=1, eps=eps)
         return mat1.float().matmul(mat2.transpose(0, 1)).type_as(mat1)
-    
+
     def _make_finite(self, scores):
         ok = scores.isfinite()
         if not ok.all():
